@@ -37,7 +37,7 @@ class Eos:
         response = muterun_js(cls.current_dir + '/js/Encrypt.js', arguments=arguments)
         if response.exitcode == 0:
             encrypted_msg = response.stdout.decode('utf8')
-            return encrypted_msg
+            return encrypted_msg.replace("\n", "")
         else:
             raise EncryptSecretException(response.stderr)
 
@@ -52,7 +52,7 @@ class Eos:
         response = muterun_js(cls.current_dir + '/js/Decrypt.js', arguments=arguments)
         if response.exitcode == 0:
             plaintext = response.stdout.decode('utf8')
-            return plaintext
+            return plaintext.replace("\n", "")
         else:
             raise EncryptSecretException(response.stderr)
 
@@ -167,4 +167,21 @@ class Eos:
     def get_chain_id(self):
         r = requests.get(self.http_address+"/v1/chain/get_info")
         response = json.loads(r.text)
-        return response["chain_id"]
\ No newline at end of file
+        return response["chain_id"]
+    
+    def get_block (self, block_num):
+        """
+        nodejs GetBlock.js "https://eos.greymass.com:443" "WIF" "eosjacklucky"
+        """
+        arguments = "'%s' '%s' '%s' '%s'" % (
+            self.http_address,
+            self.chain_id,
+            self.key_provider,
+            block_num
+        )
+        response = muterun_js(self.current_dir + '/js/GetBlock.js', arguments=arguments)
+        if response.exitcode == 0:
+            data = self.load_data(response.stdout)
+            return data
+        else:
+            raise GetAccountException(response.stderr)
\ No newline at end of file
